==> CGSocialApp-1.1.10.tar.gz: CGSocialApp/action.admin_saveusersettings.php <==
<?php
#BEGIN_LICENSE
#-------------------------------------------------------------------------
# Module: CGSocialApp (c) 2012 by Robert Campbell 
#         (calguy1000@cmsmadesimple.org)
# 
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
#
#-------------------------------------------------------------------------
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# However, as a special exception to the GPL, this software is distributed
# as an addon module to CMS Made Simple.  You may not use this software
# in any Non GPL version of CMS Made simple, or in any version of CMS
# Made simple that does not indicate clearly and obviously in its admin 
# section that the site was built with CMS Made simple.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#
#-------------------------------------------------------------------------
#END_LICENSE
if( !isset($gCms) ) exit;
if( !$this->CheckPermission('Modify Site Preferences') ) return;

$this->SetCurrentTab('usersettings');

if( isset($params['submit']) ) {
  $this->SetPreference('feu_usergroup',(int)$params['feu_usergroup']);
  $this->SetPreference('feu_ondelete_cleancheckins',(int)$params['feu_ondelete_cleancheckins']);
  $this->SetPreference('feu_tagged_priority',$params['feu_tagged_priority']);
  $this->SetPreference('feu_tagged_subject',$params['feu_tagged_subject']);
  $this->SetTemplate('feu_tagged_tpl',$params['feu_tagged_tpl']);
} else if( isset($params['reset']) ) {
  $fn = dirname(__FILE__).'/templates/orig_tagged_notification.tpl';
  $tpl = @file_get_contents($fn);
  $this->SetTemplate('feu_tagged_tpl',$tpl);
}

$this->RedirectToTab($id,'','','admin_settings');
#
# EOF
#
?>

==> CGSocialApp-1.3.1.tar.gz: CGSocialApp/action.admin_saveusersettings.php <==
<?php
#BEGIN_LICENSE
#-------------------------------------------------------------------------
# Module: CGSocialApp (c) 2012 by Robert Campbell 
#         (calguy1000@cmsmadesimple.org)
# 
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
#
#-------------------------------------------------------------------------
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# However, as a special exception to the GPL, this software is distributed
# as an addon module to CMS Made Simple.  You may not use this software
# in any Non GPL version of CMS Made simple, or in any version of CMS
# Made simple that does not indicate clearly and obviously in its admin 
# section that the site was built with CMS Made simple.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#
#-------------------------------------------------------------------------
#END_LICENSE
if( !isset($gCms) ) exit;
if( !$this->CheckPermission('Modify Site Preferences') ) return;

$this->SetCurrentTab('usersettings');

if( isset($params['submit']) ) {
  $this->SetPreference('feu_usergroup',(int)$params['feu_usergroup']);
  $this->SetPreference('feu_ondelete_cleancheckins',(int)$params['feu_ondelete_cleancheckins']);
  $this->SetPreference('feu_tagged_priority',$params['feu_tagged_priority']);
  $this->SetPreference('feu_tagged_subject',$params['feu_tagged_subject']);
  $this->SetTemplate('feu_tagged_tpl',$params['feu_tagged_tpl']);
} else if( isset($params['reset']) ) {
  $fn = __DIR__.'/templates/orig_tagged_notification.tpl';
  $tpl = @file_get_contents($fn);
  $this->SetTemplate('feu_tagged_tpl',$tpl);
}

$this->RedirectToTab($id,'','','admin_settings');
#
# EOF
#
?>
